@@ -1,20 +1,19 @@
 use super::sleep::*;
-use super::WAITS_NUM;
 use core::future::Future;
 use core::pin::Pin;
 use core::task::{Context, Poll};
 use core::time::Duration;
 
-pub fn timeout<T: Future + Unpin>(duration: Duration, future: T) -> Timeout<'static, T, WAITS_NUM> {
+pub fn timeout<T: Future + Unpin>(duration: Duration, future: T) -> Timeout<T> {
     let sleep = sleep(duration);
     Timeout { future, sleep }
 }
 
-pub struct Timeout<'a, T: Future + Unpin, const N: usize> {
+pub struct Timeout<T: Future + Unpin> {
     future: T,
-    sleep: Sleep<'a, N>,
+    sleep: Sleep,
 }
-impl<'a, T: Future + Unpin, const N: usize> Future for Timeout<'a, T, N> {
+impl<T: Future + Unpin> Future for Timeout<T> {
     type Output = Result<T::Output, ()>;
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
         // First, try polling the future
